package extenders
{

    import flash.filters.GlowFilter;
    
    import mx.containers.Box;
    import mx.containers.BoxDirection;
    import mx.containers.Grid;
    import mx.containers.GridItem;
    import mx.containers.GridRow;
    import mx.controls.Image;
    import mx.controls.Text;
    import mx.core.IToolTip;
    import mx.core.UIComponent;
    import mx.events.ToolTipEvent;
    
    import utils.Constant;
    
    //Classe qui permet d'obtenir un tooltip plus évolué
    public class AcronymTooltip extends Box implements IToolTip
    {
        protected var img:Image;
        protected var textField:Text;
        
        private var _text:String = '';
        private var info : Boolean;
        
        
        //constructeur
        public function AcronymTooltip(info:Boolean=false)
        {
        	this.info = info;
        	
            mouseEnabled = false;
            mouseChildren = false;
            setStyle("paddingLeft", 10);
            setStyle("paddingTop", 10);
            setStyle("paddingBottom", 20);
            setStyle("paddingRight", 10);
            setStyle('verticalAlign','middle');
            
           	direction = BoxDirection.HORIZONTAL;
            
            // Ajout d'un effet autour de la bulle
            filters=[new GlowFilter(0xCCCCCC,1,16,16)];
        }


		//accesseurs
        public function get text() : String 
        {     
            return null;
        }
        public function set text(value:String) : void 
        {
            _text = value;
        }
        
        
        //surcharge de createChildren
        override protected function createChildren() : void 
        {
			super.createChildren();
            
            this.setStyle('backgroundImage', Constant.bubbleClassDR);
            this.setStyle('backgroundSize', '100%');
			this.verticalScrollPolicy = "off";
			this.horizontalScrollPolicy = "off";
			
			/*
			if(info)
			{
				img = new Image();
				img.source = infoClass;
				addChild(img);
			}
			*/
			/*
			textField = new Text;
			textField.percentWidth = 100;
			textField.text = _text;
			textField.setStyle('color', 0x646464);
			textField.setStyle('fontWeight', 'bold');
			
			addChild(textField);
			*/
			
			var grid:Grid = new Grid();
			grid.setStyle('verticalGap', '0');
			
			var lineArray:Array = new Array();
			lineArray = _text.split(Constant.SYMBOL_DELIM2);
				
			for each(var line:String in lineArray)
			{
				var subLine : Array = new Array();
				subLine = line.split(Constant.SYMBOL_DELIM);
				
				var labelLine:Text = new Text();
				labelLine.setStyle('fontSize', '12');
				labelLine.htmlText = '<b>'+subLine[0]+'</b>';
				
				var labelItem:GridItem = new GridItem();
				labelItem.addChild(labelLine);
				
				var dataLine:Text = new Text();
				dataLine.setStyle('fontSize', '12');
				dataLine.text = subLine[1];
				
				var dataItem:GridItem = new GridItem();
				dataItem.addChild(dataLine);
				
				if(dataLine.text != '')
				{
					var row:GridRow = new GridRow();
					row.addChild(labelItem);
					row.addChild(dataItem);
					
					grid.addChild(row);
				}
			}
			
			addChild(grid);
			
			
			
			/*
			//pour test visuel
			setStyle('backgroundColor',0xFFFFFF);
            setStyle('backgroundAlpha',0.9);
            setStyle('borderStyle','solid');
            setStyle('borderThickness',1);
            setStyle('borderColor',0xCCCCCC);
            setStyle('cornerRadius',6);
            */
        }
        
        
        //création du tooltip customisé 'simple' pour le point
		public static function createSimpleTooltip(e:ToolTipEvent) : void
		{
			// on créé le tooltip
			e.toolTip = new AcronymTooltip();
			
            // on lui affecte le texte de la propriété tooltip de l'objet
            e.toolTip.text = (e.target as UIComponent).toolTip;
        }
        
        
     	//création du tooltip customisé 'avancé' pour le point
		public static function createAdvancedTooltip(e:ToolTipEvent) : void
		{
			// on créé le tooltip
			e.toolTip = new AcronymTooltip(true);
			
            // on lui affecte le texte de la propriété tooltip de l'objet
            e.toolTip.text = (e.target as UIComponent).toolTip;
        }
        
        
        //modification de la position pour qu'il soit centré sur le point
        //et non relatif à son container (slaveCanvas)
        public static function positionSimpleTooltip(e:ToolTipEvent) : void 
        {
        	const REPLACEMENT_CONST : int = 6;
        	
		    e.toolTip.x = (e.target as UIComponent).stage.mouseX - e.toolTip.width + REPLACEMENT_CONST;
		    e.toolTip.y = (e.target as UIComponent).stage.mouseY - e.toolTip.height;
		    
		    //on gère l'affichage des différentes bulles selon la position
		    //de la tooltip sur la scène afin qu'il n'y ait pas de sortie d'écran
		    if(e.toolTip.x < 0 && e.toolTip.y >= 0)
		    {
		    	e.toolTip.x = (e.target as UIComponent).stage.mouseX - REPLACEMENT_CONST;
		    	(e.toolTip as AcronymTooltip).setStyle('backgroundImage', Constant.bubbleClassDL);
		    }
		    if(e.toolTip.x >= 0 && e.toolTip.y < 0)
		    {
		    	e.toolTip.y = (e.target as UIComponent).stage.mouseY;
		    	(e.toolTip as AcronymTooltip).setStyle('backgroundImage', Constant.bubbleClassTR);
		    	(e.toolTip as AcronymTooltip).setStyle("paddingTop", 20);
            	(e.toolTip as AcronymTooltip).setStyle("paddingBottom", 10);
		    }
		    if(e.toolTip.x < 0 && e.toolTip.y < 0)
		    {
		    	e.toolTip.x = (e.target as UIComponent).stage.mouseX - REPLACEMENT_CONST;
		    	e.toolTip.y = (e.target as UIComponent).stage.mouseY;
		    	(e.toolTip as AcronymTooltip).setStyle('backgroundImage', Constant.bubbleClassTL);
		    	(e.toolTip as AcronymTooltip).setStyle("paddingTop", 20);
            	(e.toolTip as AcronymTooltip).setStyle("paddingBottom", 10);
		    }
        }


        //modification de la position pour qu'il soit centré sur le conteneur parent
        //et non relatif à la position de la souris par rapport au stage
        public static function positionAdvancedTooltip(e:ToolTipEvent) : void 
        {
        	const REPLACEMENT_CONST : int = 30;
        	
			e.toolTip.y = e.toolTip.y - (e.toolTip.height + REPLACEMENT_CONST);
			e.toolTip.x = e.toolTip.x - e.toolTip.width;
			
			//mieux mais provoque un bug de timer inexpliqué...
			//e.toolTip.x = ((e.target as UIComponent).parent as UIComponent).contentToGlobal( new Point(e.target.x,e.target.y)).x - e.toolTip.width + REPLACEMENT_CONST;
			//e.toolTip.y = ((e.target as UIComponent).parent as UIComponent).contentToGlobal( new Point(e.target.x,e.target.y)).y - e.toolTip.height;
		    
		    if(e.toolTip.x < 0)
		    {
		    	e.toolTip.x = REPLACEMENT_CONST;
		    	(e.toolTip as AcronymTooltip).setStyle('backgroundImage', Constant.bubbleClassDL);
		    }
        }
   
    }
}