package extenders {
	import flash.events.ContextMenuEvent;
	import flash.events.MouseEvent;
	import flash.geom.Point;
	import flash.ui.ContextMenu;
	import flash.ui.ContextMenuItem;
	
	import mx.containers.TitleWindow;
	import mx.controls.Button;
	import mx.controls.buttonBarClasses.ButtonBarButton;
	import mx.controls.ButtonBar;
	import mx.controls.DataGrid;
	import mx.controls.Menu;
	import mx.controls.PopUpButton;
	import mx.controls.dataGridClasses.DataGridColumn;
	import mx.core.Application;
	import mx.core.UIComponent;
	import mx.events.DropdownEvent;
	import mx.events.FlexEvent;
	import mx.events.ItemClickEvent;
	import mx.events.MenuEvent;
	import mx.printing.FlexPrintJob;
	
	import utils.Constant;
	import utils.CursorUtils;
	
	import view.PrintViewComparator;
	
	
	
	
	[Event(name="closeWindow", type="mx.events.FlexEvent")]
	[Event(name="minWindow", type="mx.events.FlexEvent")]
	[Event(name="maxWindow", type="mx.events.FlexEvent")]
	[Event(name="normalWindow", type="mx.events.FlexEvent")]
	[Event(name="windowResized", type="mx.events.FlexEvent")]
			
	/**
	 * @class ResizeWindow
	 * @brief A TitleWindow with Resize Enabled and Max, Min, Close Button
	 * @author Jove
	 * @version 1.2
	 */
	public class ResizeWindow extends TitleWindow {
		
		private static var resizeObj:Object;
		private static var mouseState:Number = 0;
		private static var mouseMargin:Number = 0;

		private var oWidth:Number = 0;
		private var oHeight:Number = 0;
		private var oX:Number = 0;
		private var oY:Number = 0;
		private var oPoint:Point = new Point();
		private var isMaxWindow : Boolean;
		
		private var _showWindowButtons:Boolean = false;
		private var _windowMinSize:Number = 50;

		/**
	 	 * Constructor.
	 	 * Add mouse envent to this window and application.
	 	 * initialize the old positions.
	 	 */
		public function ResizeWindow(){
			super();
			this.verticalScrollPolicy = "off";
			this.createCustomContextMenu();
			
			//this.alpha = 0.8;
			initPosition(this);
			
			this.addEventListener(MouseEvent.MOUSE_MOVE, oMouseMove);
			this.addEventListener(MouseEvent.MOUSE_OUT, oMouseOut);
			this.addEventListener(MouseEvent.MOUSE_DOWN, oMouseDown);
			//this.addEventListener(MouseEvent.MOUSE_UP, oMouseUp);
			this.addEventListener(FlexEvent.CREATION_COMPLETE, addButton);
			
			//Application.application.parent:SystemManager
			Application.application.parent.addEventListener(MouseEvent.MOUSE_UP, oMouseUp);
			Application.application.parent.addEventListener(MouseEvent.MOUSE_MOVE, oResize);
			
		
		}
		

		//création du menu contextuel personnalisé
     	private function createCustomContextMenu() : void
     	{
			var customContextMenu : ContextMenu = new ContextMenu();
			
			//cache les boutons inutiles
			customContextMenu.hideBuiltInItems();
			
			//création et ajout des items
			var menuItem1 : ContextMenuItem = new ContextMenuItem('Print comparator data table');
			customContextMenu.customItems.push(menuItem1);
			
			menuItem1.addEventListener(ContextMenuEvent.MENU_ITEM_SELECT, printCompareDG);
			
			this.contextMenu = customContextMenu;
		}
		
		
		//permet d'imprimer un tableau sur plusieurs pages
    	public function printCompareDG(event:ContextMenuEvent) : void 
    	{	
        	var children : Array = this.getChildren();
			var compareDG : DataGrid = (children[0] as DataGrid);
		    
			//création d'une instance de FlexJobPrint
	        var printJob : FlexPrintJob = new FlexPrintJob();
	        printJob.printAsBitmap = false;
	        
	        //retourne true si l'utilisateur a cliqué
	        //sur le bouton "ok" de la boite de dialogue d'impression
	        if(printJob.start()) 
	        {
	            //création du composant personnalisé qui contient
	            // ce qu'on veut imprimer
	            var printViewComparator : PrintViewComparator = new PrintViewComparator();
	            
	            //ajoute le composant à l'application
	            addChild(printViewComparator);
	            
	            //création des colonnes pour le tableau à imprimer
	            //ATTENTION: ne pas prendre directement les colonnes du tableau principales
	            //sinon elles seront modifiées, il faut en faire une copie
	            var colArray : Array = new Array();
	            for each(var column:DataGridColumn in compareDG.columns)
	            {
	            	//uniquement les colonnes affichées
	            	if(column.visible)
	            	{
	            		var object:Object = new Object();
	            		object['headerText'] = column.headerText;
	            		object['dataTipField'] = (column.dataTipField==null) ? '' : column.dataTipField;
	            	
	            		colArray.push(object);
	            	}
	            }
				
				//rempli le composant avec les bonnes données
				printViewComparator.initPrintDG(colArray, compareDG.dataProvider);
	            
	            //renseigne le composant sur les tailles à prendre
	            //en fonction de l'imprimante sélectionnée
	            printViewComparator.width = printJob.pageWidth;
	            printViewComparator.height = printJob.pageHeight;
	             
	            //si le tableau à imprimer peut tenir complètement (toutes ses lignes)
	            //sur une seule page, on l'ajoute au printJob
	            if(!printViewComparator.printDG.validNextPage)
	            {
	                printJob.addObject(printViewComparator);
	            }
	            //sinon, il y a plusieurs pages à imprimer
	            else
	            {
	                //on ajoute la première page
	                printJob.addObject(printViewComparator);
	                
	                //puis les autres pages tant qu'il y en a
	                while(printViewComparator.printDG.validNextPage) 
	                {
	                    printViewComparator.printDG.nextPage();
	                    printJob.addObject(printViewComparator);   
	                }
	            }
	            
	            //toutes les pages ont été mises dans la liste d'impression,
	            //on retire le composant pour libérer de la mémoire 
	            removeChild(printViewComparator);
	            
	            //envoi de la requête d'impression 
	            printJob.send();
	        } 
		}
		
		

		/**
		 * Version qui permet d'imprimer le rendu graphique
		 * mais ne gère pas lorsque le tableau comporte un certain
		 * nombre de lignes qui s'étendent sur plusieurs pages
		 * 
		 * 
		//impression du tableau uniquement
     	private function printCompareDG(event:ContextMenuEvent) : void
     	{
     		var children : Array = this.getChildren();
			var compareDG : DataGrid = (children[0] as DataGrid);
			    
     		var printJob : PrintJob = new PrintJob();
		    printJob.start();
		    
     		var oldWith : Number = compareDG.width;
     		var oldHeight : Number = compareDG.height;
     		var oldFontSize : Number = compareDG.getStyle("fontSize");
     		
     		compareDG.width = printJob.pageWidth-20;
		    compareDG.height = printJob.pageHeight;
		    compareDG.setStyle("fontSize", "10");
		    
     		validateNow();
     		
     		if(printJob.orientation == PrintJobOrientation.LANDSCAPE) compareDG.rotation = 90;
            
            try 
     		{
		    	printJob.addPage(compareDG);
		    }
            catch(e:Error) 
            {
            	//Alert.show("Had problem adding the data table to print job: " + e);
            }
            
            try 
			{
        		printJob.send();
            }
            catch(e:Error) 
            {
            	Alert.show("Had problem printing: " + e);
            }
            
            compareDG.width = oldWith;
 			compareDG.height = oldHeight;
 			compareDG.setStyle("fontSize", oldFontSize);
     		
 			validateNow();
     	}
		**/
		
		
		public function set showWindowButtons(show:Boolean):void{
			_showWindowButtons = show;
			if(titleBar != null){
				addButton(new FlexEvent(""));
				//titleBar.addEventListener(MouseEvent.MOUSE_DOWN, runMoveWindow);
				//titleBar.addEventListener(MouseEvent.MOUSE_UP, stopMoveWindow);
			}
		}
		
		private function runMoveWindow(event:MouseEvent) : void
		{
			CursorUtils.changeCursor(Constant.WINDOW_MOVE, -6, -6);
		}
		
		private function stopMoveWindow(event:MouseEvent) : void
		{
			CursorUtils.changeCursor(null, 0, 0);
		}
		
		public function get showWindowButtons():Boolean{
			return _showWindowButtons;
		}
		
		public function set windowMinSize(size:Number):void{
			if(size > 0){
				_windowMinSize = size;
			}
		}
		
		public function get windowMinSize():Number{
			return _windowMinSize;
		}
		
		private static function initPosition(obj:Object):void{
			obj.oHeight = obj.height;
			obj.oWidth = obj.width;
			obj.oX = obj.x;
			obj.oY = obj.y;
		}
		
		/**
		 * Set the first global point that mouse down on the window.
		 * @param The MouseEvent.MOUSE_DOWN
		 */
		private function oMouseDown(event:MouseEvent):void{
			if(mouseState != Constant.SIDE_OTHER){
				resizeObj = event.currentTarget;
				initPosition(resizeObj);
				oPoint.x = resizeObj.mouseX;
				oPoint.y = resizeObj.mouseY;
				oPoint = this.localToGlobal(oPoint);
			}
		}
		
		/**
		 * Clear the resizeObj and also set the latest position.
		 * @param The MouseEvent.MOUSE_UP
		 */
		private function oMouseUp(event:MouseEvent):void{
			if(resizeObj != null){
				initPosition(resizeObj);
			}
			resizeObj = null;
		}
		
		/**
		 * Show the mouse arrow when not draging.
		 * Call oResize(event) to resize window when mouse is inside the window area.
		 * @param The MouseEvent.MOUSE_MOVE
		 */
		private function oMouseMove(event:MouseEvent):void{
			if(resizeObj == null){
				var xPosition:Number = Application.application.parent.mouseX;
				var yPosition:Number = Application.application.parent.mouseY;
				
				if(xPosition >= (this.x + this.width - mouseMargin) && yPosition >= (this.y + this.height - mouseMargin))
				{
					CursorUtils.changeCursor(Constant.LEFT_OBLIQUE_SIZE, -6, -6);
					mouseState = Constant.SIDE_RIGHT | Constant.SIDE_BOTTOM;
				}
				
				else if(xPosition <= (this.x + mouseMargin) && yPosition <= (this.y + mouseMargin))
				{
					/*
					CursorUtils.changeCursor(Constant.LEFT_OBLIQUE_SIZE, -6, -6);
					mouseState = Constant.SIDE_LEFT | Constant.SIDE_TOP;
					*/
					mouseState = Constant.SIDE_OTHER;
					CursorUtils.changeCursor(null, 0, 0);
				}
				
				else if(xPosition <= (this.x + mouseMargin) && yPosition >= (this.y + this.height - mouseMargin))
				{
					CursorUtils.changeCursor(Constant.RIGHT_OBLIQUE_SIZE, -6, -6);
					mouseState = Constant.SIDE_LEFT | Constant.SIDE_BOTTOM;
				}
				
				else if(xPosition >= (this.x + this.width - mouseMargin) && yPosition <= (this.y + mouseMargin))
				{
					/*
					CursorUtils.changeCursor(Constant.RIGHT_OBLIQUE_SIZE, -6, -6);
					mouseState = Constant.SIDE_RIGHT | Constant.SIDE_TOP;
					*/
					mouseState = Constant.SIDE_OTHER;
					CursorUtils.changeCursor(null, 0, 0);
				}
				
				else if(xPosition >= (this.x + this.width - mouseMargin))
				{
					CursorUtils.changeCursor(Constant.HORIZONTAL_SIZE, -9, -9);
					mouseState = Constant.SIDE_RIGHT;	
				}
				
				else if(xPosition <= (this.x + mouseMargin))
				{
					CursorUtils.changeCursor(Constant.HORIZONTAL_SIZE, -9, -9);
					mouseState = Constant.SIDE_LEFT;
				}
				
				else if(yPosition >= (this.y + this.height - mouseMargin))
				{
					CursorUtils.changeCursor(Constant.VERTICAL_SIZE, -9, -9);
					mouseState = Constant.SIDE_BOTTOM;
				}
				
				/*else if(yPosition <= (this.y + mouseMargin))
				{
					CursorUtils.changeCursor(Constant.VERTICAL_SIZE, -9, -9);
					mouseState = Constant.SIDE_TOP;
				}*/
				
				else
				{
					mouseState = Constant.SIDE_OTHER;
					CursorUtils.changeCursor(null, 0, 0);
				}
				
			}
			//Use SystemManager to listen the mouse reize event, so we needn't handle the event at the current object.
			//oResize(event);
		}
		
		/**
		 * Hide the arrow when not draging and moving out the window.
		 * @param The MouseEvent.MOUSE_MOVE
		 */
		private function oMouseOut(event:MouseEvent):void{
			if(resizeObj == null){
				CursorUtils.changeCursor(null, 0, 0);
			}
		}
		
		/**
		 * Resize when the draging window, resizeObj is not null.
		 * @param The MouseEvent.MOUSE_MOVE
		 */
		private function oResize(event:MouseEvent):void{
			if(resizeObj != null){	
				resizeObj.stopDragging();
				var xPlus:Number = Application.application.parent.mouseX - resizeObj.oPoint.x;
				var yPlus:Number = Application.application.parent.mouseY - resizeObj.oPoint.y;
			    switch(mouseState){
			    	case Constant.SIDE_RIGHT | Constant.SIDE_BOTTOM:
			    		resizeObj.width = resizeObj.oWidth + xPlus > _windowMinSize ? resizeObj.oWidth + xPlus : _windowMinSize;
		    			resizeObj.height = resizeObj.oHeight + yPlus > _windowMinSize ? resizeObj.oHeight + yPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_LEFT | Constant.SIDE_TOP:
		    			resizeObj.x = xPlus < resizeObj.oWidth - _windowMinSize ? resizeObj.oX + xPlus: resizeObj.x;
		    			resizeObj.y = yPlus < resizeObj.oHeight - _windowMinSize ? resizeObj.oY + yPlus : resizeObj.y;
			    		resizeObj.width = resizeObj.oWidth - xPlus > _windowMinSize ? resizeObj.oWidth - xPlus : _windowMinSize;
		    			resizeObj.height = resizeObj.oHeight - yPlus > _windowMinSize ? resizeObj.oHeight - yPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_LEFT | Constant.SIDE_BOTTOM:
			    		resizeObj.x = xPlus < resizeObj.oWidth - _windowMinSize ? resizeObj.oX + xPlus: resizeObj.x;
			    		resizeObj.width = resizeObj.oWidth - xPlus > _windowMinSize ? resizeObj.oWidth - xPlus : _windowMinSize;
		    			resizeObj.height = resizeObj.oHeight + yPlus > _windowMinSize ? resizeObj.oHeight + yPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_RIGHT | Constant.SIDE_TOP:
			    		resizeObj.y = yPlus < resizeObj.oHeight - _windowMinSize ? resizeObj.oY + yPlus : resizeObj.y;
			    		resizeObj.width = resizeObj.oWidth + xPlus > _windowMinSize ? resizeObj.oWidth + xPlus : _windowMinSize;
		    			resizeObj.height = resizeObj.oHeight - yPlus > _windowMinSize ? resizeObj.oHeight - yPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_RIGHT:
			    		resizeObj.width = resizeObj.oWidth + xPlus > _windowMinSize ? resizeObj.oWidth + xPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_LEFT:
			    		resizeObj.x = xPlus < resizeObj.oWidth - _windowMinSize ? resizeObj.oX + xPlus: resizeObj.x;
			    		resizeObj.width = resizeObj.oWidth - xPlus > _windowMinSize ? resizeObj.oWidth - xPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_BOTTOM:
			    		resizeObj.height = resizeObj.oHeight + yPlus > _windowMinSize ? resizeObj.oHeight + yPlus : _windowMinSize;
			    		break;
			    	case Constant.SIDE_TOP:
			    		resizeObj.y = yPlus < resizeObj.oHeight - _windowMinSize ? resizeObj.oY + yPlus : resizeObj.y;
			    		resizeObj.height = resizeObj.oHeight - yPlus > _windowMinSize ? resizeObj.oHeight - yPlus : _windowMinSize;
			    		break;
			    }
			    
			    var children : Array = this.getChildren();
			    (children[0] as UIComponent).width = this.width-28;
			    (children[0] as UIComponent).height = this.height-52;
			    //Alert.show(this.height + ' - ' + (children[0] as UIComponent).height);
			    dispatchEvent(new FlexEvent("windowResized"));
			}
		}
		
		
		//--------------------------------------------------------------------------
		//
		//  Control the window buttons.
		//
		//--------------------------------------------------------------------------
		
		private var windowMinButton : Button;
		private var windowMaxButton : Button;
		private var windowCloseButton : Button;
		private var popupButton : PopUpButton;
		private var menu : Menu;
		private var buttonBar : ButtonBar;
		private var listColumn : Array = new Array();
		private var listColumnName : Array = new Array();
		[Bindable] private var columnChoiceIsOpen : Boolean = false;
		
		
		public function setListColumn(lst:Array) : void
		{
			listColumn = new Array();
			listColumn = lst;
		}
		
		/**
		 * Add the window buttons and layout them.
		 * @param The FlexEvent.CREATION_COMPLETE
		 */
		private function addButton(event:FlexEvent):void{
			//Alert.show(event.type.toString());
			if(_showWindowButtons){
				/*
				if(windowMinButton == null){
					windowMinButton = new Button();
					windowMinButton.width=10;
					windowMinButton.height=10;
					windowMinButton.focusEnabled=false;
					windowMinButton.setStyle("upSkin", Constant.WINDOW_MIN_BUTTON_1);
					windowMinButton.setStyle("overSkin", Constant.WINDOW_MIN_BUTTON_2);
					windowMinButton.setStyle("downSkin", Constant.WINDOW_MIN_BUTTON_2);
					windowMinButton.addEventListener(MouseEvent.CLICK, windowMinButton_clickHandler);
					titleBar.addChild(windowMinButton);
				}*/
				if(windowMaxButton == null){
					windowMaxButton = new Button();
					windowMaxButton.width=10;
					windowMaxButton.height=10;
					windowMaxButton.focusEnabled=false;
					windowMaxButton.setStyle("upSkin", Constant.WINDOW_NORMAL_BUTTON_1);
					windowMaxButton.setStyle("overSkin", Constant.WINDOW_NORMAL_BUTTON_2);
					windowMaxButton.setStyle("downSkin", Constant.WINDOW_NORMAL_BUTTON_2);
					windowMaxButton.addEventListener(MouseEvent.CLICK, windowMaxButton_clickHandler);
					titleBar.addChild(windowMaxButton);
					isMaxWindow = true;
				}
				if(windowCloseButton == null){
					windowCloseButton = new Button();
					windowCloseButton.width=10;
					windowCloseButton.height=10;
					windowCloseButton.focusEnabled=false;
					windowCloseButton.setStyle("upSkin", Constant.WINDOW_CLOSE_BUTTON_1);
					windowCloseButton.setStyle("overSkin", Constant.WINDOW_CLOSE_BUTTON_2);
					windowCloseButton.setStyle("downSkin", Constant.WINDOW_CLOSE_BUTTON_2);
					windowCloseButton.addEventListener(MouseEvent.CLICK, windowCloseButton_clickHandler);
					titleBar.addChild(windowCloseButton);
				}
				if(popupButton == null)
				{
					popupButton = new PopUpButton();
					popupButton.label = ' ';
					popupButton.width = 140;
					popupButton.height = 20;
					popupButton.openAlways = true;
					popupButton.addEventListener(FlexEvent.INITIALIZE, initColumnChoiceButton);
					popupButton.addEventListener(DropdownEvent.OPEN, openedPopup);
					popupButton.addEventListener(DropdownEvent.CLOSE, closedPopup);
					titleBar.addChild(popupButton);
				}	
				if(buttonBar == null)
				{
					
					buttonBar = new ButtonBar();
					buttonBar.dataProvider = new Array('print','choose columns', '');
					buttonBar.width = 230;
					buttonBar.height = 20;
					buttonBar.focusEnabled = false;
					buttonBar.addEventListener(FlexEvent.CREATION_COMPLETE, manageButtons);
					buttonBar.addEventListener(ItemClickEvent.ITEM_CLICK, buttonBarManager);
					titleBar.addChild(buttonBar);
				}
				
							
				layoutWindowButtons();
			}
			else{
				/*titleBar.removeChild(windowMinButton);
				windowMinButton = null;*/
				titleBar.removeChild(windowMaxButton);
				windowMaxButton = null;
				titleBar.removeChild(windowCloseButton);
				windowCloseButton = null;
			}
			
			
		}
		
		
		private function buttonBarManager(event:ItemClickEvent) : void
		{
			if(event.index==0)
            {
            	printCompareDG(null);
            }
            else if(event.index==1)
            {
            	if(columnChoiceIsOpen) this.popupButton.close();
            	else this.popupButton.open();
            }
		}
	
		private function openedPopup(event:DropdownEvent) : void
		{
			columnChoiceIsOpen = true;
		}
		
		
		private function closedPopup(event:DropdownEvent) : void
		{
			columnChoiceIsOpen = false;
		}
		
		
		private function initColumnChoiceButton(event:FlexEvent) : void
		{
			for each(var column:DataGridColumn in listColumn)
			{
				if(column.headerText!='Details')
				{
					var obj : Object = new Object();
					obj['label'] = column.headerText;
					obj['id'] = column.dataTipField;
					obj['type'] = 'check';
					obj['toggled'] = true;
					
					listColumnName.push(obj);
				}
			}
			
		    menu = new Menu();
            menu.variableRowHeight = true;
            menu.dataProvider = listColumnName;
            menu.addEventListener(MenuEvent.CHANGE, manageColumnDisplay);
            popupButton.popUp = menu;
        }
        
        
        //permet d'afficher/masquer la colonne sélectionnée dans le menu
        private function manageColumnDisplay(evt:MenuEvent) : void 
        {
            if(menu.dataDescriptor.getType(evt.item) == "check") 
            {
            	var id:String = evt.item.id;
            	var childen:Array = this.getChildren();
            	var comparatorDG : DataGrid = childen[0];
            	
				var found:Boolean = false;
				var i:int = 0;
				
				while(!found && i<comparatorDG.columnCount)
				{
					var column:DataGridColumn = comparatorDG.columns[i];
					if(column.dataTipField == id)
					{
						found = true;
					}
					else
					{
						i++;
					}
				}
				
				if(found)
				{
                	menu.dataDescriptor.isToggled(evt.item) == true ? 
                				(comparatorDG.columns[i] as DataGridColumn).visible = true : 
                				(comparatorDG.columns[i] as DataGridColumn).visible = false;
    			}
            }
		}
        
        
        
        
		private function manageButtons(event:FlexEvent) : void
		{
			(buttonBar.getChildAt(2) as ButtonBarButton).visible=false;
		}
		/*
		private function windowMinButton_clickHandler(event:MouseEvent):void{
			dispatchEvent(new FlexEvent("minWindow"));
		}
		*/
		private function windowMaxButton_clickHandler(event:MouseEvent) : void
		{
			if(isMaxWindow) {
				windowMaxButton.setStyle("upSkin", Constant.WINDOW_MAX_BUTTON_1);
				windowMaxButton.setStyle("overSkin", Constant.WINDOW_MAX_BUTTON_2);
				windowMaxButton.setStyle("downSkin", Constant.WINDOW_MAX_BUTTON_2);
				
				isMaxWindow = false;
				dispatchEvent(new FlexEvent("maxWindow"));
				
			}
			else 
			{
				windowMaxButton.setStyle("upSkin", Constant.WINDOW_NORMAL_BUTTON_1);
				windowMaxButton.setStyle("overSkin", Constant.WINDOW_NORMAL_BUTTON_2);
				windowMaxButton.setStyle("downSkin", Constant.WINDOW_NORMAL_BUTTON_2);
				
				isMaxWindow = true;
				dispatchEvent(new FlexEvent("normalWindow"));
			}
		}
		
		private function windowCloseButton_clickHandler(event:MouseEvent):void{
			dispatchEvent(new FlexEvent("closeWindow"));
		}
		
		private function layoutWindowButtons():void{
			/*if(windowMinButton != null){
				windowMinButton.move(titleBar.width - 10 * 3  - 6 - 6 - 6, (titleBar.height - 10) / 2);
			}*/
			if(windowMaxButton != null){
				windowMaxButton.move(titleBar.width - 44, (titleBar.height - 10) / 2);
			}
			if(windowCloseButton != null){
				windowCloseButton.move(titleBar.width - 24, (titleBar.height - 10) / 2);
			}
			if(buttonBar != null)
			{
				buttonBar.move(titleBar.width - buttonBar.width - 34, (titleBar.height-buttonBar.height) / 2);
			}
			if(popupButton != null)
			{
				popupButton.move(titleBar.width -(buttonBar.width/2) - 84, (titleBar.height-buttonBar.height) / 2);
			}			
		}
		
		override protected function layoutChrome(unscaledWidth:Number, unscaledHeight:Number):void{
			super.layoutChrome(unscaledWidth, unscaledHeight);
			layoutWindowButtons();
		}
	}
}