package model
{
	import mx.collections.ArrayCollection;
	
	import utils.Constant;
	
	public class AcronymDetailModel
	{
		public var id : int;
		public var tableTitle : String;
		public var write : String;
		public var object : String;
		public var note : String;
		public var inSource : String;
		public var stat : String;
		public var redStars : String;
		public var origin : String;
		public var references : ArrayCollection;
		public var eformats : String;
		
		public function AcronymDetailModel(id:int, acronymModel:AcronymModel)
		{
			this.id = id;

			this.tableTitle = acronymModel.name + ' (' + acronymModel.meaning.meaning + ')';
			
			var format : String = '';
			var passed : Boolean = false;
			for each(var dataFormat:String in acronymModel.meaning.formats)
			{
				format += Constant.SYMBOL_INF_DBL_HTML + acronymModel.simbad + ' ' + dataFormat + Constant.SYMBOL_SUP_DBL_HTML + ' \nor ';
				passed = true;
			}
			if(passed) format = format.slice(0, format.length-4);
			this.write = format;
			
			this.object = acronymModel.object + " (<a href='"+Constant.LINK_FIND_OBJECT+acronymModel.object+"' target='_blank'><u><font color='#0101ee'>SIMBAD class:</font></u></a> " + acronymModel.oType + ')';
			this.note = acronymModel.remark;
			this.inSource = "<a href='"+Constant.LINK_FIND_SOURCE+acronymModel.inSource+"' target='_blank'><u><font color='#0101ee'>"+acronymModel.inSource+"</font></u></a>";
			this.stat = (acronymModel.stat=='=') ? Constant.IS_INCORPORATED : acronymModel.stat;
			
			if(acronymModel.useName != Constant.SYMBOL_NOT_EMPTY)
			{
				this.redStars = Constant.LIB_AVOID+'<b>'+acronymModel.name+'</b>'+Constant.LIB_PREFER+"<a href='"+Constant.LINK_FIND_PREFER+acronymModel.useName+"' target='_blank'><u><font color='#0101ee'>"+acronymModel.useName+"</font></u></a>";				
			}
			else
			{
				this.redStars = '';
			}
						
			(acronymModel.origin == '') ? this.origin='' : this.origin = '<b>'+acronymModel.origin+'</b>' + ' = ' +Constant['ORIGIN_'.toString().concat(acronymModel.origin)];
			
			this.references = new ArrayCollection();
			for each(var acronymReferenceModel:AcronymReferenceModel in acronymModel.references)
			{
				this.references.addItem(new AcronymDetailReferenceModel(acronymReferenceModel));
			}
			
			this.eformats = '';
			for each(var eformatStr:String in acronymModel.eformat)
			{
				this.eformats += Constant.LIB_EFORMAT + "<a href='"+Constant.LINK_FIND_EFORMAT+eformatStr+"' target='_blank'><u><font color='#0101ee'>"+eformatStr+"</font></u></a>"+'\n';
			}
			
		}
		
		
		public static function getLabelByType(type:String) : String
		{
			var label : String = '';
			
			switch (type)
			{
				case 'write' : 		label = Constant.LIB_WRITE;
									break;
				case 'object' : 	label = Constant.LIB_OBJECT;
									break;
				case 'note' : 		label = Constant.LIB_NOTE;
									break;
				case 'inSource' : 	label = Constant.LIB_IN_SOURCE;
									break;
				case 'stat' : 		label = Constant.LIB_STAT;
									break;
				case 'origin' : 	label = Constant.LIB_ORIGIN;
									break;
				case 'redStars' : 	label = Constant.LIB_RED_STARS;
									break;
				case 'eformats' : 	label = Constant.LIB_E;
									break;
				case 'references' : label = Constant.LIB_REFERENCES;
									break;
				case 'ref' : 		label = Constant.LIB_REF;
									break;
				case 'by' : 		label = Constant.LIB_BY;
									break;
				case 'nameRef' : 	label = Constant.LIB_NAME_REF;
									break;
				case 'title' : 		label = Constant.LIB_TITLE;
									break;
				case 'tables' : 	label = Constant.LIB_TABLES;
									break;
				
				default	:			break;
			}
			
			return label;
		}
		
		
		public static function getListObjects(acronymDetailModelArray:Array) : Array
		{
			var listObjects : Array = new Array();
			
			listObjects.push('write');
			listObjects.push('object');
			listObjects.push('note');
			listObjects.push('inSource');
			listObjects.push('stat');
			listObjects.push('redStars');
			listObjects.push('origin');
			listObjects.push('eformats');
			
			var nbRef : int = 0;
			nbRef = getNumberOfReferences(acronymDetailModelArray);
			
			//Alert.show(nbRef.toString());
			
			if(nbRef > 0) listObjects.push('references');
			for(var j:int=0; j<nbRef; j++)
			{
				listObjects = AcronymDetailReferenceModel.addReference(listObjects);
			}
			
			
			return listObjects;
		}
		
		
		public static function getNumberOfReferences(acronymDetailModelArray:Array) : int
		{
			//le nombre max de référence
			var nbMaxRef : int = 0;
			for each(var adm : AcronymDetailModel in acronymDetailModelArray)
			{
				if(adm.references.length > nbMaxRef) nbMaxRef = adm.references.length;
			}
			
			return nbMaxRef;
		} 
		
		
		public static function getNumberOfLines(acronymDetailModelArray:Array) : int
		{
			var nbLine : int = 0;
			
			//les champs par défaut
			nbLine = AcronymDetailModel.getListObjects(acronymDetailModelArray).length;
			
			//le nombre max de référence
			var nbMaxRef : int = 0;
			for each(var adm : AcronymDetailModel in acronymDetailModelArray)
			{
				if(adm.references.length > nbMaxRef) nbMaxRef = adm.references.length;
			}
			nbLine += (nbMaxRef*4);
			
			//Alert.show(nbLine.toString());
			return nbLine; 
		}

	}
}